#
# spec file for package 
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%if %{defined suse_version}
%define apxs /usr/sbin/apxs2
BuildRequires:  apache2-devel apache2-prefork apache2-worker 
%else
%define apxs /usr/sbin/apxs
BuildRequires:  httpd-devel
%endif
%define apache apache2
%define apache_libexecdir %(%{apxs} -q LIBEXECDIR)
%define apache_sysconfdir %(%{apxs} -q SYSCONFDIR)
%define apache_includedir %(%{apxs} -q INCLUDEDIR)
%define apache_serverroot %(%{apxs} -q PREFIX)
%define apache_localstatedir %(%{apxs} -q LOCALSTATEDIR)
%define apache_mmn        %(MMN=$(%{apxs} -q LIBEXECDIR)_MMN; test -x $MMN && $MMN)

Name:           apache2-mod_musicindex
Version:        1.3.6
Release:        3.2
License:        GNU Lesser General Public License version 2.1 or later (LGPLv2.1+)
Group:          Productivity/Networking/Web/Servers
%if %{defined suse_version}
Requires:       apache2 
Requires:       %{apache_mmn}
%else
Requires:       httpd
%endif
Summary:        Nice Displaying of Directories containing Music Files
URL:            http://www.parisc-linux.org/~varenet/musicindex/
Source:         http://www.parisc-linux.org/~varenet/musicindex/mod_musicindex-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc make autoconf automake libtool pkgconfig
BuildRequires:  libvorbis-devel libogg-devel flac-devel
BuildRequires:  libarchive-devel
BuildRequires:  libmysqlclient-devel
%if 0%{?_with_mad}
BuildRequires:  libmad-devel
BuildRequires:  libid3tag-devel
BuildRequires:  libmp4v2-devel
Provides:       %{name}-with-mp3 = %{version}
Provides:       %{name}-with-mp4 = %{version}
Provides:       %{name}-with-mad = %{version}
%endif

%description
mod_musicindex is an Apache module aimed at being a C alternative to the Perl
module Apache::MP3. It allows nice displaying of directories containing MP3,
Ogg Vorbis, FLAC, or MP4/AAC files, including sorting them on various fields,
streaming/downloading them, constructing playlists, and searching. It also
provides features such as RSS and Podcast feeds, multiple CSS support, and
archive downloads.

%if !0%{?_with_mad}
Note that this package is built *without* MP3/MP4 support, as it requires
libmad, which potentially infringes on software patents.
%endif

%prep
%setup -q -n "mod_musicindex-%{version}"

%build
%configure \
    --with-apxs="%{apxs}" \
    --disable-rpath \
2>&1|tee conf.rpm.log
r="${PIPESTATUS[0]}"
if [ "$r" != "0" ]; then
    echo "ERROR: configure failed" >&2
    exit $r
fi

for x in Vorbis FLAC \
%if 0%{?_with_mad}
MP3 MP4 \
%endif
; do
    grep -q -E '^Building '"$x"' codec support: .*YES$' conf.rpm.log || {
        echo "ERROR: missing support for codec: $x" >&2
        exit 1
    }
done
%if !0%{?_with_mad}
for x in MP3 MP4; do
    grep -q -E '^Building '"$x"' codec support: .*NO$' conf.rpm.log || {
        echo "ERROR: forbidden support for codec: $x" >&2
        exit 1
    }
done
%endif

for x in "flat file" mysql; do
    grep -q -E '^Building '"$x"' backend: .*YES$' conf.rpm.log || {
        echo "ERROR: missing support for backend: $x" >&2
        exit 1
    }
done
for x in archive; do
    grep -q -E '^Building '"$x"' output support: .*YES$' conf.rpm.log || {
        echo "ERROR: missing support for output: $x" >&2
        exit 1
    }
done

%__make %{?_smp_flags}

%install
%makeinstall

%find_lang mod_musicindex

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%files -f mod_musicindex.lang
%defattr(-,root,root)
%doc AUTHORS BUGS COPYING ChangeLog README
%doc README.Handlers TODO UPGRADING
%{apache_libexecdir}/mod_musicindex.so
%{_datadir}/mod_musicindex

%changelog
* Tue Nov  1 2011 pascal.bleser@opensuse.org
- initial version (1.3.6)
